==> edc_dx_review-1.0.0.tar.gz: edc_dx_review-1.0.0/edc_dx_review/model_mixins/clinical_review_followup/clinical_review_followup_dm_model_mixin.py <==
from django.db import models
from django.utils.html import format_html
from django.utils.safestring import mark_safe
from edc_constants.choices import YES_NO_NA
from edc_constants.constants import NOT_APPLICABLE
from edc_model import models as edc_models

from ...utils import get_list_model_app


class ClinicalReviewDmModelMixin(models.Model):
    dm_test = models.CharField(
        verbose_name="Since last seen, was the patient tested for diabetes?",
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        help_text=format_html(
            "{}",
            mark_safe(
                "Note: Select `not applicable` if diagnosis previously reported. <BR>"
                "`Since last seen` includes today.<BR>"
                "If `yes', complete the initial review CRF<BR>"
                "If `not applicable`, complete the review CRF."
            ),  # nosec B308, B703
        ),
    )

    dm_test_date = models.DateField(
        verbose_name="Date test requested",
        null=True,
        blank=True,
    )

    dm_reason = models.ManyToManyField(
        f"{get_list_model_app()}.reasonsfortesting",
        related_name="dm_reason",
        verbose_name="Why was the patient tested for diabetes?",
        blank=True,
    )

    dm_reason_other = edc_models.OtherCharField()

    dm_dx = models.CharField(
        verbose_name=format_html(
            "As of today, was the patient <u>{}</u> diagnosed with diabetes?", "newly"
        ),
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
    )

    class Meta:
        abstract = True

==> edc_dx_review-1.0.1.tar.gz: edc_dx_review-1.0.1/edc_dx_review/model_mixins/clinical_review_followup/clinical_review_followup_dm_model_mixin.py <==
from django.db import models
from django.utils.html import format_html
from django.utils.safestring import mark_safe
from edc_constants.choices import YES_NO_NA
from edc_constants.constants import NOT_APPLICABLE
from edc_model import models as edc_models

from ...utils import get_list_model_app


class ClinicalReviewDmModelMixin(models.Model):
    dm_test = models.CharField(
        verbose_name="Since last seen, was the patient tested for diabetes?",
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        help_text=format_html(
            "{html}",
            html=mark_safe(
                "Note: Select `not applicable` if diagnosis previously reported. <BR>"
                "`Since last seen` includes today.<BR>"
                "If `yes', complete the initial review CRF<BR>"
                "If `not applicable`, complete the review CRF."
            ),  # nosec B308, B703
        ),
    )

    dm_test_date = models.DateField(
        verbose_name="Date test requested",
        null=True,
        blank=True,
    )

    dm_reason = models.ManyToManyField(
        f"{get_list_model_app()}.reasonsfortesting",
        related_name="dm_reason",
        verbose_name="Why was the patient tested for diabetes?",
        blank=True,
    )

    dm_reason_other = edc_models.OtherCharField()

    dm_dx = models.CharField(
        verbose_name=format_html(
            "As of today, was the patient <u>{text}</u> diagnosed with diabetes?",
            text="newly",
        ),
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
    )

    class Meta:
        abstract = True
